# project2_db-module

#### pypi python module
#### mysql-connector-python connector
#### git action : push -> module update

##### install
```
pip install jarudaDB
```
##### use
```
import databases as db

dbh = db.DBHandler(user='your user', host='your host', database='your db name', pw='your password')
```

